================
Crystal geometry
================

These guides describe conventions for the unit cell, symmetry operations and relevant
reference frames, and also show how to operate with vectors in the crystal and sample
reference frames.

.. nbgallery::
    :hidden:

    crystal_reference_frame.ipynb
    crystal_directions.ipynb
    point_groups.ipynb
    inverse_pole_figures.ipynb